"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VueOOP = exports.Utils = exports.VueOOPOptions = void 0;
const tslib_1 = require("tslib");
const Model_1 = tslib_1.__importDefault(require("./models/Model"));
const Repository_1 = tslib_1.__importDefault(require("./repositories/Repository"));
const Registry_1 = tslib_1.__importDefault(require("./Registry"));
const Utils = tslib_1.__importStar(require("./utils"));
exports.Utils = Utils;
const graphql_1 = require("graphql");
const parser_1 = require("graphql/language/parser");
const utils_1 = require("./utils");
const registry = Registry_1.default.getInstance();
registry.set('Model', Model_1.default);
registry.set('Repository', Repository_1.default);
class VueOOPOptions {
    constructor() {
        this.rest = true;
        this.graphql = false;
        this.schema = null;
        this.schemaUrl = null;
        this.debug = false;
    }
}
exports.VueOOPOptions = VueOOPOptions;
async function VueOOP(Vue, options) {
    const config = {
        rest: true,
        graphql: false,
        schema: null,
        schemaUrl: null,
        debug: false,
        ...options,
    };
    if (config.schemaUrl && config.debug) {
        config.schema = await utils_1.fetchIntrospectionSchema(config.schemaUrl)
            .then(graphql_1.buildClientSchema.bind(null))
            .then(graphql_1.printSchema.bind(null))
            .then(parser_1.parse.bind(null));
    }
    registry.set('Config', config);
    Vue.prototype.$registry = registry;
    Vue.mixin({
        beforeCreate() {
            if (this.$parent || registry.has('Vue'))
                return;
            registry.set('Vue', this);
        },
    });
}
exports.VueOOP = VueOOP;
exports.default = VueOOP;
var Registry_2 = require("./Registry");
Object.defineProperty(exports, "Registry", { enumerable: true, get: function () { return Registry_2.default; } });
var Repository_2 = require("./repositories/Repository");
Object.defineProperty(exports, "Repository", { enumerable: true, get: function () { return Repository_2.default; } });
var Model_2 = require("./models/Model");
Object.defineProperty(exports, "Model", { enumerable: true, get: function () { return Model_2.default; } });
var Collection_1 = require("./models/Collection");
Object.defineProperty(exports, "Collection", { enumerable: true, get: function () { return Collection_1.default; } });
var BaseException_1 = require("./models/Exceptions/BaseException");
Object.defineProperty(exports, "BaseException", { enumerable: true, get: function () { return BaseException_1.default; } });
var InvalidArgumentException_1 = require("./models/Exceptions/InvalidArgumentException");
Object.defineProperty(exports, "InvalidArgumentException", { enumerable: true, get: function () { return InvalidArgumentException_1.default; } });
var UnexpectedException_1 = require("./models/Exceptions/UnexpectedException");
Object.defineProperty(exports, "UnexpectedException", { enumerable: true, get: function () { return UnexpectedException_1.default; } });
var UnauthorizedException_1 = require("./models/Exceptions/UnauthorizedException");
Object.defineProperty(exports, "UnauthorizedException", { enumerable: true, get: function () { return UnauthorizedException_1.default; } });
var ValidationException_1 = require("./models/Exceptions/ValidationException");
Object.defineProperty(exports, "ValidationException", { enumerable: true, get: function () { return ValidationException_1.default; } });
//# sourceMappingURL=index.js.map